@@ -1,9 +1,9 @@
 # Copyright (c) 2018 Sean Vig
 
-from pathlib import Path
 import importlib.util
 import os
 import sys
+from pathlib import Path
 
 from cffi import FFI, VerificationError
 from pywayland.ffi_build import ffi_builder as pywayland_ffi
@@ -384,6 +384,37 @@ struct wlr_data_source {
 void wlr_data_source_destroy(struct wlr_data_source *source);
 """
 
+# types/wlr_export_dmabuf_v1.h
+CDEF += """
+struct wlr_export_dmabuf_manager_v1 {
+    struct wl_global *global;
+    struct wl_list frames; // wlr_export_dmabuf_frame_v1::link
+
+    struct wl_listener display_destroy;
+
+    struct {
+        struct wl_signal destroy;
+    } events;
+    ...;
+};
+
+struct wlr_export_dmabuf_frame_v1 {
+    struct wl_resource *resource;
+    struct wlr_export_dmabuf_manager_v1 *manager;
+    struct wl_list link; // wlr_export_dmabuf_manager_v1::frames
+
+    struct wlr_output *output;
+
+    bool cursor_locked;
+
+    struct wl_listener output_commit;
+    ...;
+};
+
+struct wlr_export_dmabuf_manager_v1 *wlr_export_dmabuf_manager_v1_create(
+    struct wl_display *display);
+"""
+
 # types/wlr_foreign_toplevel_management_v1.h
 CDEF += """
 struct wlr_foreign_toplevel_manager_v1 {
@@ -1873,6 +1904,43 @@ struct wlr_virtual_keyboard_manager_v1* wlr_virtual_keyboard_manager_v1_create(
     struct wl_display *display);
 """
 
+# types/wlr_virtual_pointer_v1.h
+CDEF += """
+struct wlr_virtual_pointer_manager_v1 {
+    struct wl_global *global;
+    struct wl_list virtual_pointers;
+    struct wl_listener display_destroy;
+    struct {
+        struct wl_signal new_virtual_pointer;
+        struct wl_signal destroy;
+    } events;
+    ...;
+};
+
+struct wlr_virtual_pointer_v1 {
+    struct wlr_input_device input_device;
+    struct wl_resource *resource;
+    struct wlr_event_pointer_axis axis_event[2];
+    enum wl_pointer_axis axis;
+    bool axis_valid[2];
+    struct wl_list link;
+    struct {
+        struct wl_signal destroy;
+    } events;
+    ...;
+};
+
+struct wlr_virtual_pointer_v1_new_pointer_event {
+    struct wlr_virtual_pointer_v1 *new_pointer;
+    struct wlr_seat *suggested_seat;
+    struct wlr_output *suggested_output;
+    ...;
+};
+
+struct wlr_virtual_pointer_manager_v1* wlr_virtual_pointer_manager_v1_create(
+    struct wl_display *display);
+"""
+
 # types/wlr_xcursor_manager.h
 CDEF += """
 struct wlr_xcursor_manager *wlr_xcursor_manager_create(const char *name,
@@ -2315,10 +2383,11 @@ SOURCE = """
 #include <wlr/backend/libinput.h>
 #include <wlr/render/allocator.h>
 #include <wlr/render/wlr_renderer.h>
-#include <wlr/types/wlr_cursor.h>
 #include <wlr/types/wlr_compositor.h>
+#include <wlr/types/wlr_cursor.h>
 #include <wlr/types/wlr_data_control_v1.h>
 #include <wlr/types/wlr_data_device.h>
+#include <wlr/types/wlr_export_dmabuf_v1.h>
 #include <wlr/types/wlr_foreign_toplevel_management_v1.h>
 #include <wlr/types/wlr_gamma_control_v1.h>
 #include <wlr/types/wlr_idle.h>
@@ -2343,6 +2412,7 @@ SOURCE = """
 #include <wlr/types/wlr_seat.h>
 #include <wlr/types/wlr_server_decoration.h>
 #include <wlr/types/wlr_virtual_keyboard_v1.h>
+#include <wlr/types/wlr_virtual_pointer_v1.h>
 #include <wlr/types/wlr_xcursor_manager.h>
 #include <wlr/types/wlr_xdg_decoration_v1.h>
 #include <wlr/types/wlr_xdg_output_v1.h>
